import { Caveat } from "./caveat";
import { MacaroonClass, Satisfier } from "./types";
/**
 * @description utility function to get an array of caveat instances from
 * a raw macaroon.
 * @param {string} macaroon - raw macaroon to retrieve caveats from
 * @returns {Caveat[]} array of caveats on the macaroon
 */
export declare function getCaveatsFromMacaroon(rawMac: string): Caveat[];
/**
 * @description verifyMacaroonCaveats will check if a macaroon is valid or
 * not based on a set of satisfiers to pass as general caveat verifiers. This will also run
 * against caveat.verifyCaveats to ensure that satisfyPrevious will validate
 * @param {string} macaroon A raw macaroon to run a verifier against
 * @param {String} secret The secret key used to sign the macaroon
 * @param {(Satisfier | Satisfier[])} satisfiers a single satisfier or list of satisfiers used to verify caveats
 * @param {Object} [options] An optional options object that will be passed to the satisfiers.
 * In many circumstances this will be a request object, for example when this is used in a server
 * @returns {boolean}
 */
export declare function verifyMacaroonCaveats(rawMac: string, secret: string, satisfiers?: Satisfier | Satisfier[], options?: any): boolean;
export declare function getRawMacaroon(mac: MacaroonClass): string;
